@@ -22,7 +22,7 @@ from . import merakitoolkitsupport
 __author__ = "Giovanni Augusto"
 __copyright__ = "Copyright (C) 2022 Giovanni Augusto"
 __license__ = "MIT"
-__version__ = "1.0.2"
+__version__ = "1.0.3"
 
 
 class MerakiToolkit():
@@ -332,7 +332,7 @@ class MerakiToolkit():
                     # add MIMEBase object to MIMEMultipart object
                     msg_root.attach(mime)
             except Exception as err: # pylint: disable=broad-except
-                print("An error occurred while opening the logo image: ",err)
+                print("An error occurred while opening logo image: ",err)
 
         msg_html = merakitoolkitsupport.generate_email_body(
             "templatehtml.j2",
